#[non_exhaustive]pub struct ChannelSubscriptionGiftV1Payload {
pub broadcaster_user_id: UserId,
pub broadcaster_user_login: DisplayName,
pub broadcaster_user_name: UserName,
pub cumulative_total: Option<i64>,
pub is_anonymous: bool,
pub tier: SubscriptionTier,
pub total: i64,
pub user_id: Option<UserId>,
pub user_login: Option<DisplayName>,
pub user_name: Option<UserName>,
}Available on crate feature
eventsub only.Expand description
channel.subscription.gift response payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_user_id: UserIdThe broadcaster user ID.
broadcaster_user_login: DisplayNameThe broadcaster login.
broadcaster_user_name: UserNameThe broadcaster display name.
cumulative_total: Option<i64>The number of subscriptions gifted by this user in the channel. This value is null for anonymous gifts or if the gifter has opted out of sharing this information.
is_anonymous: boolWhether the subscription gift was anonymous.
tier: SubscriptionTierThe tier of subscriptions in the subscription gift.
total: i64The number of subscriptions in the subscription gift.
user_id: Option<UserId>The user ID of the user who sent the subscription gift. Set to null if it was an anonymous subscription gift.
user_login: Option<DisplayName>The user login of the user who sent the gift. Set to null if it was an anonymous subscription gift.
user_name: Option<UserName>The user display name of the user who sent the gift. Set to null if it was an anonymous subscription gift.