#[non_exhaustive]pub struct GetClipsRequest {
pub broadcaster_id: Option<UserId>,
pub game_id: Option<CategoryId>,
pub id: Vec<String>,
pub after: Option<Cursor>,
pub before: Option<Cursor>,
pub ended_at: Option<Timestamp>,
pub first: Option<usize>,
pub started_at: Option<Timestamp>,
}helix only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_id: Option<UserId>ID of the broadcaster for whom clips are returned. The number of clips returned is determined by the first query-string parameter (default: 20). Results are ordered by view count.
game_id: Option<CategoryId>ID of the game for which clips are returned. The number of clips returned is determined by the first query-string parameter (default: 20). Results are ordered by view count.
id: Vec<String>ID of the clip being queried. Limit: 100.
after: Option<Cursor>Cursor for forward pagination: tells the server where to start fetching the next set of results, in a multi-page response. This applies only to queries specifying broadcaster_id or game_id. The cursor value specified here is from the pagination response field of a prior query.
before: Option<Cursor>Cursor for backward pagination: tells the server where to start fetching the next set of results, in a multi-page response. This applies only to queries specifying broadcaster_id or game_id. The cursor value specified here is from the pagination response field of a prior query.
ended_at: Option<Timestamp>Ending date/time for returned clips, in RFC3339 format. (Note that the seconds value is ignored.) If this is specified, started_at also must be specified; otherwise, the time period is ignored.
first: Option<usize>Maximum number of objects to return. Maximum: 100. Default: 20.
started_at: Option<Timestamp>Starting date/time for returned clips, in RFC3339 format. (Note that the seconds value is ignored.) If this is specified, ended_at also should be specified; otherwise, the ended_at date/time will be 1 week after the started_at value.
Implementations
Sourceimpl GetClipsRequest
impl GetClipsRequest
Sourcepub fn builder() -> GetClipsRequestBuilder<((), (), (), (), (), (), (), ())>
pub fn builder() -> GetClipsRequestBuilder<((), (), (), (), (), (), (), ())>
Create a builder for building GetClipsRequest.
On the builder, call .broadcaster_id(...)(optional), .game_id(...)(optional), .id(...)(optional), .after(...)(optional), .before(...)(optional), .ended_at(...)(optional), .first(...)(optional), .started_at(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of GetClipsRequest.