#[non_exhaustive]pub struct BanUserBody {
pub duration: Option<u32>,
pub reason: String,
pub user_id: UserId,
}Available on crate feature
helix only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.duration: Option<u32>Duration of the (optional) timeout in seconds.
To ban a user indefinitely, don’t include this field.
To put a user in a timeout, include this field and specify the timeout period, in seconds. The minimum timeout is 1 second and the maximum is 1,209,600 seconds (2 weeks). To end a user’s timeout early, set this field to 1, or send an Unban user request.
reason: StringThe reason the user is being banned or put in a timeout. The text is user defined and limited to a maximum of 500 characters.
user_id: UserIdThe ID of the user to ban or put in a timeout.
Implementations
Sourceimpl BanUserBody
impl BanUserBody