#[non_exhaustive]pub struct CreatePollBody {
pub broadcaster_id: UserId,
pub title: String,
pub duration: i64,
pub choices: Vec<NewPollChoice>,
pub bits_voting_enabled: Option<bool>,
pub bits_per_vote: Option<i64>,
pub channel_points_voting_enabled: Option<bool>,
pub channel_points_per_vote: Option<i64>,
}helix only.Expand description
Body Parameters for Create Poll
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_id: UserIdThe broadcaster running polls. Provided broadcaster_id must match the user_id in the user OAuth token.
title: StringQuestion displayed for the poll. Maximum: 60 characters.
duration: i64Total duration for the poll (in seconds). Minimum: 15. Maximum: 1800.
choices: Vec<NewPollChoice>Array of the poll choices. Minimum: 2 choices. Maximum: 5 choices.
bits_voting_enabled: Option<bool>Indicates if Bits can be used for voting. Default: false
bits_per_vote: Option<i64>Number of Bits required to vote once with Bits. Minimum: 0. Maximum: 10000.
channel_points_voting_enabled: Option<bool>Indicates if Channel Points can be used for voting. Default: false
channel_points_per_vote: Option<i64>Number of Channel Points required to vote once with Channel Points. Minimum: 0. Maximum: 1000000.
Implementations
Sourceimpl CreatePollBody
impl CreatePollBody
Sourcepub fn builder() -> CreatePollBodyBuilder<((), (), (), (), (), (), (), ())>
pub fn builder() -> CreatePollBodyBuilder<((), (), (), (), (), (), (), ())>
Create a builder for building CreatePollBody.
On the builder, call .broadcaster_id(...), .title(...), .duration(...), .choices(...), .bits_voting_enabled(...)(optional), .bits_per_vote(...)(optional), .channel_points_voting_enabled(...)(optional), .channel_points_per_vote(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of CreatePollBody.