#[non_exhaustive]pub struct GetBroadcasterSubscriptionsRequest {
pub broadcaster_id: UserId,
pub user_id: Vec<UserId>,
pub after: Option<Cursor>,
pub first: Option<String>,
}helix only.Expand description
Query Parameters for Get Broadcaster Subscriptions
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_id: UserIdUser ID of the broadcaster. Must match the User ID in the Bearer token.
user_id: Vec<UserId>Unique identifier of account to get subscription status of. Accepts up to 100 values.
after: Option<Cursor>Cursor for forward pagination: tells the server where to start fetching the next set of results, in a multi-page response. The cursor value specified here is from the pagination response field of a prior query.
first: Option<String>Number of values to be returned per page. Limit: 100. Default: 20.
Implementations
Sourceimpl GetBroadcasterSubscriptionsRequest
impl GetBroadcasterSubscriptionsRequest
Sourcepub fn builder() -> GetBroadcasterSubscriptionsRequestBuilder<((), (), (), ())>
pub fn builder() -> GetBroadcasterSubscriptionsRequestBuilder<((), (), (), ())>
Create a builder for building GetBroadcasterSubscriptionsRequest.
On the builder, call .broadcaster_id(...), .user_id(...)(optional), .after(...)(optional), .first(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of GetBroadcasterSubscriptionsRequest.