#[non_exhaustive]pub struct ContentClassification {
pub category: String,
pub level: i64,
}Available on crate feature
pubsub only.Expand description
Classification for content according to AutoMod
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.category: StringCategory for classification
On twitch, these are the different categories available for AutoMod
- Aggression Threatening, inciting, or promoting violence or other harm
- Bullying: namecalling Name-calling, insults, or antagonization
- Disability Demonstrating hatred or prejudice based on perceived or actual mental or physical abilities
- Sexuality, sex, or gender Demonstrating hatred or prejudice based on sexual identity, sexual orientation, gender identity, or gender expression
- Misogyny: misogyny Demonstrating hatred or prejudice against women, including sexual objectification
- Race, ethnicity, or religion: racism Demonstrating hatred or prejudice based on race, ethnicity, or religion
- Sex-based terms: sexwords Sexual acts, anatomy
- Swearing: swearing Swear words, &*^!#@%
level: i64Level of classification, eg. how strongly related the classification is related according to AutoMod