#[non_exhaustive]pub struct SubGift {Show 14 fields
pub benefit_end_month: Option<i64>,
pub channel_id: UserId,
pub channel_name: UserName,
pub months: i64,
pub multi_month_duration: Option<i64>,
pub recipient_display_name: DisplayName,
pub recipient_id: UserId,
pub recipient_user_name: UserName,
pub sub_plan: SubscriptionTier,
pub sub_plan_name: String,
pub time: Timestamp,
pub user_id: UserId,
pub user_name: UserName,
pub display_name: DisplayName,
/* private fields */
}Available on crate feature
pubsub only.Expand description
A gifted subscription happened
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.benefit_end_month: Option<i64>Unknown
channel_id: UserIdID of the channel that has been subscribed or subgifted
channel_name: UserNameName of the channel that has been subscribed or subgifted
months: i64Months
multi_month_duration: Option<i64>Duration of subscription, e.g 1, 3 or 6
recipient_display_name: DisplayNameDisplay name of user that received gifted subscription
recipient_id: UserIdUsername of user that received gifted subscription
recipient_user_name: UserNameUsername of user that received gifted subscription
sub_plan: SubscriptionTierSubscription plan
sub_plan_name: StringName of subscription plan
time: TimestampTime when pubsub message was sent
user_id: UserIdID of user that purchased gifted subscription
user_name: UserNameUsername of user that purchased gifted subscription
display_name: DisplayNameDisplay name of user that purchased gifted subscription